<?php
namespace SM\Controller;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use SM\Service\AssinaturaDigitalCDAService;
use Zeedhi\Framework\DTO\Row;
use Zeedhi\Framework\HTTP\Kernel;

class AssinaturaDigitalCDAController {

    protected $asssinaDigitalCDAservice;
    protected $httpKernel;

    public function __construct(AssinaturaDigitalCDAService $asssinaDigitalCDAservice, Kernel $httpKernel){
        $this->asssinaDigitalCDAservice = $asssinaDigitalCDAservice;
        $this->httpKernel = $httpKernel;
    }

    public function uploadtoCertsing(Request $request, Response $response){
        try {

             $upload = $this->asssinaDigitalCDAservice->uploadtoCertsing();

             $response->addDataSet(new DataSet("RESULT", $upload));

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function createSignatureCertsing(Request $request, Response $response){
        try {

            $create = $this->asssinaDigitalCDAservice->createSignatureCertsing();

            $response->addDataSet(new DataSet("RESULT", $create));

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function callbackCertsing(Request $request, Response $response){
        try {
            $parametros = $request->getParameters();
            $nrorg = $this->httpKernel->getHttpRequest()->getHeaders()->get("nrorg");
            
            $this->asssinaDigitalCDAservice->callbackCertsing($parametros, $nrorg);

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function incluirSignatario(Request $request, Response $response){
        try {
            
            $this->asssinaDigitalCDAservice->incluirSignatario($request);

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function excluirSignatario(Request $request, Response $response){
        try {
            
            $this->asssinaDigitalCDAservice->excluirSignatario($request);

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function reenviarSolicitacao(Request $request, Response $response){
        try {
            
            $this->asssinaDigitalCDAservice->reenviarSolicitacao($request);

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function excluirdocumento(Request $request, Response $response){
        try {
            $this->asssinaDigitalCDAservice->excluirdocumento($request);

        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}